API Reference
=============

Correction Interface
--------------------
.. automodule:: unac.correction.interface
   :members:
   :undoc-members:

Registry for Correction algorithms
----------------------------------
.. automodule:: unac.correction.registry
   :members:

Comparing correction results
----------------------------
.. automodule:: unac.util.compare
   :members:

Configuration handling
----------------------
.. automodule:: unac.util.config
   :members:

internal data structure for storing data from isotope labeling experiments
--------------------------------------------------------------------------
.. automodule:: unac.util.data
   :members:

data export
-----------
.. automodule:: unac.util.exports
   :members:

data import
-----------
.. automodule:: unac.util.imports
   :members:

plotting routines
-----------------
.. automodule:: unac.util.plots
   :members:
